==> knative-model-6.0.0-sources.jar: io/fabric8/knative/eventing/v1/BrokerStatusFluent.java <==
package io.fabric8.knative.eventing.v1;

import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.AddressableFluent;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface BrokerStatusFluent<A extends BrokerStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAddress instead.
   * @return The buildable object.
   */
  @Deprecated
  public Addressable getAddress();
  public Addressable buildAddress();
  public A withAddress(Addressable address);
  public Boolean hasAddress();
  public A withNewAddress(String url);
  public BrokerStatusFluent.AddressNested<A> withNewAddress();
  public BrokerStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
  public BrokerStatusFluent.AddressNested<A> editAddress();
  public BrokerStatusFluent.AddressNested<A> editOrNewAddress();
  public BrokerStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  public A addToConditions(Integer index,Condition item);
  public A setToConditions(Integer index,Condition item);
  public A addToConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Condition> getConditions();
  public List<Condition> buildConditions();
  public Condition buildCondition(Integer index);
  public Condition buildFirstCondition();
  public Condition buildLastCondition();
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.knative.internal.pkg.apis.Condition... conditions);
  public Boolean hasConditions();
  public BrokerStatusFluent.ConditionsNested<A> addNewCondition();
  public BrokerStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
  public BrokerStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,Condition item);
  public BrokerStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public BrokerStatusFluent.ConditionsNested<A> editFirstCondition();
  public BrokerStatusFluent.ConditionsNested<A> editLastCondition();
  public BrokerStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public interface AddressNested<N> extends Nested<N>,AddressableFluent<BrokerStatusFluent.AddressNested<N>>{
    public N and();
    public N endAddress();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,ConditionFluent<BrokerStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}

==> knative-model-6.4.0-sources.jar: io/fabric8/knative/eventing/v1/BrokerStatusFluent.java <==
package io.fabric8.knative.eventing.v1;

import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.AddressableFluent;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface BrokerStatusFluent<A extends BrokerStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAddress instead.
   * @return The buildable object.
   */
  @Deprecated
  public Addressable getAddress();
  public Addressable buildAddress();
  public A withAddress(Addressable address);
  public Boolean hasAddress();
  public A withNewAddress(String url);
  public BrokerStatusFluent.AddressNested<A> withNewAddress();
  public BrokerStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
  public BrokerStatusFluent.AddressNested<A> editAddress();
  public BrokerStatusFluent.AddressNested<A> editOrNewAddress();
  public BrokerStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  public A addToConditions(Integer index,Condition item);
  public A setToConditions(Integer index,Condition item);
  public A addToConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Condition> getConditions();
  public List<Condition> buildConditions();
  public Condition buildCondition(Integer index);
  public Condition buildFirstCondition();
  public Condition buildLastCondition();
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.knative.internal.pkg.apis.Condition... conditions);
  public Boolean hasConditions();
  public BrokerStatusFluent.ConditionsNested<A> addNewCondition();
  public BrokerStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
  public BrokerStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,Condition item);
  public BrokerStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public BrokerStatusFluent.ConditionsNested<A> editFirstCondition();
  public BrokerStatusFluent.ConditionsNested<A> editLastCondition();
  public BrokerStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
  public String getDeadLetterSinkUri();
  public A withDeadLetterSinkUri(String deadLetterSinkUri);
  public Boolean hasDeadLetterSinkUri();
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public interface AddressNested<N> extends Nested<N>,AddressableFluent<BrokerStatusFluent.AddressNested<N>>{
    public N and();
    public N endAddress();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,ConditionFluent<BrokerStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}
